Struct pidgeon_cli::service::modbus::time::UTC_PLUS_ONE
source · struct UTC_PLUS_ONE {
__private_field: (),
}Fields
__private_field: ()Methods from Deref<Target = FixedOffset>
sourcepub fn local_minus_utc(&self) -> i32
pub fn local_minus_utc(&self) -> i32
Returns the number of seconds to add to convert from UTC to the local time.
sourcepub fn utc_minus_local(&self) -> i32
pub fn utc_minus_local(&self) -> i32
Returns the number of seconds to add to convert from the local time to UTC.